ecls_school = read.table('C:\\GRE2016\\Data\\ecls_school.dat', na.strings='.')

names(ecls_school) = c('child_id','school_id',
	                 'math_kf','read_kf','math_ks','read_ks', 
                       'attent_kf','attent_m','attent_d', 
                       'poverty','gender','age','hrs_day')

head(ecls_school)

library(nlme)

## Empty Model

read.empty.lme = lme(read_ks~1, random=~1|school_id, data=ecls_school, na.action="na.omit")
summary(read.empty.lme)

#Linear mixed-effects model fit by REML
# Data: ecls_school 
#       AIC      BIC    logLik
#  128834.7 128857.8 -64414.35
#
#Random effects:
# Formula: ~1 | school_id
#        (Intercept) Residual
#StdDev:     6.17717  12.6572
#
#Fixed effects: read_ks ~ 1 
#               Value Std.Error    DF  t-value p-value
#(Intercept) 46.42545 0.2340764 15217 198.3346       0
#
#Standardized Within-Group Residuals:
#       Min         Q1        Med         Q3        Max 
#-3.5296423 -0.5617592 -0.1457811  0.3240408  8.6599276 
#
#Number of Observations: 16096
#Number of Groups: 879 


read.empty <- nlme(read_ks ~ beta_00 + u_0j,
                     data=ecls_school,                      
                     fixed=beta_00~1,                      
                     random=u_0j~1,
                     group=~school_id,                      
                     start=c(beta_00=35),
                     na.action="na.omit")                       

summary(read.empty)

#Nonlinear mixed-effects model fit by maximum likelihood
#  Model: read_ks ~ beta_00 + u_0j 
# Data: ecls_school 
#       AIC      BIC    logLik
#  128833.6 128856.7 -64413.82
#
#Random effects:
# Formula: u_0j ~ 1 | school_id
#           u_0j Residual
#StdDev: 6.17256 12.65722
#
#Fixed effects: beta_00 ~ 1 
#           Value Std.Error    DF  t-value p-value
#beta_00 46.42543 0.2339431 15217 198.4475       0
#
#Standardized Within-Group Residuals:
#       Min         Q1        Med         Q3        Max 
#-3.5291180 -0.5618730 -0.1457700  0.3240057  8.6599351 
#
#Number of Observations: 16096
#Number of Groups: 879 

## Including Attention at both levels

read.attent.lme = lme(read_ks ~ attent_m + attent_d, random=~attent_d|school_id, 
                     data=ecls_school, na.action="na.omit")

summary(read.attent.lme)

#Linear mixed-effects model fit by REML
# Data: ecls_school 
#       AIC      BIC    logLik
#  126424.5 126478.3 -63205.25
#
#Random effects:
# Formula: ~attent_d | school_id
# Structure: General positive-definite, Log-Cholesky parametrization
#            StdDev    Corr  
#(Intercept)  5.965063 (Intr)
#attent_d     2.457366 0.946 
#Residual    11.691416       
#
#Fixed effects: read_ks ~ attent_m + attent_d 
#               Value Std.Error    DF   t-value p-value
#(Intercept) 46.31773 0.2240592 15216 206.72089       0
#attent_m     7.13140 0.7490439   877   9.52067       0
#attent_d     7.37018 0.1724695 15216  42.73325       0
# Correlation: 
#         (Intr) attnt_m
#attent_m  0.011        
#attent_d  0.410 -0.015 
#
#Standardized Within-Group Residuals:
#       Min         Q1        Med         Q3        Max 
#-2.9288027 -0.5476303 -0.1396126  0.3182398  9.1171154 
#
#Number of Observations: 16096
#Number of Groups: 879 

read.attent <- nlme(read_ks ~ (beta_00 + beta_01 * attent_m + u_0j) +
                              (beta_10 + u_1j) * attent_d,
                     data=ecls_school,                      
                     fixed=beta_00+beta_01+beta_10~1,                      
                     random=u_0j+u_1j~1,
                     group=~school_id,                      
                     start=c(beta_00=35, beta_01=0, beta_10=0),
                     na.action="na.omit")                       

summary(read.attent)

#Nonlinear mixed-effects model fit by maximum likelihood
#  Model: read_ks ~ (beta_00 + beta_01 * attent_m + u_0j) + (beta_10 +      u_1j) * attent_d 
# Data: ecls_school 
#       AIC      BIC    logLik
#  126422.7 126476.5 -63204.37
#
#Random effects:
# Formula: list(u_0j ~ 1, u_1j ~ 1)
# Level: school_id
# Structure: General positive-definite, Log-Cholesky parametrization
#         StdDev    Corr 
#u_0j      5.957006 u_0j 
#u_1j      2.450260 0.948
#Residual 11.691486      
#
#Fixed effects: beta_00 + beta_01 + beta_10 ~ 1 
#           Value Std.Error    DF   t-value p-value
#beta_00 46.31774 0.2238324 15215 206.93043       0
#beta_01  7.13143 0.7482553 15215   9.53075       0
#beta_10  7.36974 0.1723452 15215  42.76153       0
# Correlation: 
#        bet_00 bet_01
#beta_01  0.011       
#beta_10  0.410 -0.015
#
#Standardized Within-Group Residuals:
#       Min         Q1        Med         Q3        Max 
#-2.9282911 -0.5477618 -0.1396963  0.3182539  9.1172264 
#
#Number of Observations: 16096
#Number of Groups: 879 

## Full Model

ecls_school$hrs_day5 = ecls_school$hrs_day - 5

read.full.lme = lme(read_ks ~ attent_m + attent_d + hrs_day5 + attent_d*hrs_day5, random=~attent_d|school_id, 
                     data=ecls_school, na.action="na.omit")

summary(read.full.lme)

#Linear mixed-effects model fit by REML
# Data: ecls_school 
#       AIC      BIC    logLik
#  126408.4 126477.5 -63195.18
#
#Random effects:
# Formula: ~attent_d | school_id
# Structure: General positive-definite, Log-Cholesky parametrization
#            StdDev    Corr  
#(Intercept)  5.879262 (Intr)
#attent_d     2.463178 0.947 
#Residual    11.690013       
#
#Fixed effects: read_ks ~ attent_m + attent_d + hrs_day5 + attent_d * hrs_day5 
#                     Value Std.Error    DF   t-value p-value
#(Intercept)       46.36304 0.2216326 15215 209.18869  0.0000
#attent_m           7.70152 0.7488384   876  10.28463  0.0000
#attent_d           7.39248 0.1726300 15215  42.82269  0.0000
#hrs_day5           0.62675 0.1301287   876   4.81636  0.0000
#attent_d:hrs_day5  0.05797 0.1003554 15215   0.57761  0.5635
# Correlation: 
#                  (Intr) attnt_m attnt_d hrs_d5
#attent_m           0.017                       
#attent_d           0.411 -0.011                
#hrs_day5           0.044  0.138   0.019        
#attent_d:hrs_day5  0.021  0.001  -0.010   0.411
#
#Standardized Within-Group Residuals:
#       Min         Q1        Med         Q3        Max 
#-2.9390798 -0.5496159 -0.1387862  0.3182049  9.1120374 
#
#Number of Observations: 16096
#Number of Groups: 879 


read.full <- nlme(read_ks ~ (beta_00 + beta_01 * attent_m + beta_02 * (hrs_day - 5) + u_0j) +
                            (beta_10 + beta_11 * (hrs_day - 5) + u_1j) * attent_d,
                     data=ecls_school,                      
                     fixed=beta_00+beta_01+beta_02+beta_10+beta_11~1,                      
                     random=u_0j+u_1j~1,
                     group=~school_id,                      
                     start=c(beta_00=35, beta_01=0, beta_02= 0, beta_10=0, beta_11=0),
                     na.action="na.omit")                       

summary(read.full)

#Nonlinear mixed-effects model fit by maximum likelihood
#  Model: read_ks ~ (beta_00 + beta_01 * attent_m + beta_02 * (hrs_day -
#      5) + u_0j) + (beta_10 + beta_11 * (hrs_day - 5) + u_1j) *      attent_d 
# Data: ecls_school 
#       AIC      BIC    logLik
#  126401.4 126470.5 -63191.69
#
#Random effects:
# Formula: list(u_0j ~ 1, u_1j ~ 1)
# Level: school_id
# Structure: General positive-definite, Log-Cholesky parametrization
#         StdDev    Corr 
#u_0j      5.866963 u_0j 
#u_1j      2.448671 0.952
#Residual 11.690164      
#
#Fixed effects: beta_00 + beta_01 + beta_02 + beta_10 + beta_11 ~ 1 
#           Value Std.Error    DF   t-value p-value
#beta_00 46.36303 0.2212894 15213 209.51309  0.0000
#beta_01  7.70149 0.7476662 15213  10.30071  0.0000
#beta_02  0.62662 0.1299268 15213   4.82284  0.0000
#beta_10  7.39165 0.1723735 15213  42.88157  0.0000
#beta_11  0.05808 0.1002049 15213   0.57960  0.5622
# Correlation: 
#        bet_00 bet_01 bet_02 bet_10
#beta_01  0.017                     
#beta_02  0.044  0.138              
#beta_10  0.411 -0.011  0.019       
#beta_11  0.021  0.001  0.412 -0.010
#
#Standardized Within-Group Residuals:
#       Min         Q1        Med         Q3        Max 
#-2.9389295 -0.5497938 -0.1387757  0.3181153  9.1122412 
#
#Number of Observations: 16096
#Number of Groups: 879 


################# lme4 ################# 

library(lme4)

empty.lmer <- lmer(read_ks ~ 1 + (1 | school_id), data = ecls_school, REML = TRUE)

summary(empty.lmer)

#Linear mixed model fit by REML ['lmerMod']
#Formula: read_ks ~ 1 + (1 | school_id)
#   Data: ecls_school
#
#REML criterion at convergence: 128828.7
#
#Scaled residuals: 
#    Min      1Q  Median      3Q     Max 
#-3.5296 -0.5618 -0.1458  0.3240  8.6599 
#
#Random effects:
# Groups    Name        Variance Std.Dev.
# school_id (Intercept)  38.16    6.177  
# Residual              160.20   12.657  
#Number of obs: 16096, groups:  school_id, 879
#
#Fixed effects:
#            Estimate Std. Error t value
#(Intercept)  46.4254     0.2341   198.3

attent.lmer <- lmer(read_ks ~ attent_m + attent_d + (attent_d | school_id), data = ecls_school, REML = TRUE)

summary(attent.lmer)

#Linear mixed model fit by REML ['lmerMod']
#Formula: read_ks ~ attent_m + attent_d + (attent_d | school_id)
#   Data: ecls_school
#
#REML criterion at convergence: 126410.5
#
#Scaled residuals: 
#    Min      1Q  Median      3Q     Max 
#-2.9288 -0.5476 -0.1396  0.3182  9.1171 
#
#Random effects:
# Groups    Name        Variance Std.Dev. Corr
# school_id (Intercept)  35.582   5.965       
#           attent_d      6.038   2.457   0.95
# Residual              136.689  11.691       
#Number of obs: 16096, groups:  school_id, 879
#
#Fixed effects:
#            Estimate Std. Error t value
#(Intercept)  46.3177     0.2241  206.72
#attent_m      7.1314     0.7490    9.52
#attent_d      7.3702     0.1725   42.73
#
#Correlation of Fixed Effects:
#         (Intr) attnt_m
#attent_m  0.011        
#attent_d  0.410 -0.015 

full.lmer <- lmer(read_ks ~ attent_m + attent_d + hrs_day5 + attent_d*hrs_day5 + (attent_d | school_id), data = ecls_school, REML = TRUE)

summary(full.lmer)

#Linear mixed model fit by REML ['lmerMod']
#Formula: read_ks ~ attent_m + attent_d + hrs_day5 + attent_d * hrs_day5 +  
#    (attent_d | school_id)
#   Data: ecls_school
#
#REML criterion at convergence: 126390.4
#
#Scaled residuals: 
#    Min      1Q  Median      3Q     Max 
#-2.9391 -0.5496 -0.1388  0.3182  9.1120 
#
#Random effects:
# Groups    Name        Variance Std.Dev. Corr
# school_id (Intercept)  34.566   5.879       
#           attent_d      6.066   2.463   0.95
# Residual              136.657  11.690       
#Number of obs: 16096, groups:  school_id, 879
#
#Fixed effects:
#                  Estimate Std. Error t value
#(Intercept)       46.36304    0.22163  209.19
#attent_m           7.70153    0.74884   10.28
#attent_d           7.39246    0.17262   42.82
#hrs_day5           0.62675    0.13013    4.82
#attent_d:hrs_day5  0.05796    0.10035    0.58
#
#Correlation of Fixed Effects:
#            (Intr) attnt_m attnt_d hrs_d5
#attent_m     0.017                       
#attent_d     0.411 -0.011                
#hrs_day5     0.044  0.138   0.019        
#attnt_d:h_5  0.021  0.001  -0.010   0.411

