ODS HTML CLOSE;
ODS LISTING;

DATA ecls_school;
	INFILE 'C:\GRE2016\data\ecls_school.dat';
	INPUT child_id school_id
	      math_kf read_kf math_ks read_ks 
          attent_kf attent_m attent_d 
          poverty gender age hrs_day;
RUN;

** Empty Model **;

PROC MIXED DATA = ecls_school NOCLPRINT COVTEST;
	CLASS school_id;
	MODEL read_ks = / SOLUTION DDFM = BW;
	RANDOM INTERCEPT / SUBJECT = school_id TYPE = UN;
RUN;

/*
                                 Covariance Parameter Estimates

                                                    Standard         Z
              Cov Parm     Subject      Estimate       Error     Value      Pr > Z

              UN(1,1)      school_id     38.1525      2.3272     16.39      <.0001
              Residual                    160.21      1.8378     87.17      <.0001


                                         Fit Statistics

                              -2 Res Log Likelihood        128828.7
                              AIC (smaller is better)      128832.7
                              AICC (smaller is better)     128832.7
                              BIC (smaller is better)      128842.3


                                Null Model Likelihood Ratio Test

                                  DF    Chi-Square      Pr > ChiSq

                                   1       1879.13          <.0001


                                   Solution for Fixed Effects

                                         Standard
                Effect       Estimate       Error      DF    t Value    Pr > |t|

                Intercept     46.4254      0.2341     878     198.34      <.0001
*/

PROC NLMIXED DATA = ecls_school;
*level-2;
	b_0j = beta_00 + u_0j;
*level-1 - without residual term;
	pred = b_0j;

	MODEL read_ks ~ NORMAL(pred,sigma2_e);
	RANDOM u_0j ~ NORMAL([0], [sigma2_u0]) SUBJECT = school_id;
	PARMS beta_00 = 35 sigma2_e = 80 sigma2_u0 = 20;
RUN;

/*
                                          Fit Statistics

                             -2 Log Likelihood                 128828
                             AIC (smaller is better)           128834
                             AICC (smaller is better)          128834
                             BIC (smaller is better)           128848


                                       Parameter Estimates

                        Standard
   Parameter  Estimate     Error    DF  t Value  Pr > |t|   Alpha     Lower     Upper  Gradient

   beta_00     46.4405    0.2351   878   197.54    <.0001    0.05   45.9791   46.9019  0.270905
   sigma2_e     160.10    1.8355   878    87.23    <.0001    0.05    156.50    163.70   -0.0252
   sigma2_u0   38.5728    2.3694   878    16.28    <.0001    0.05   33.9223   43.2232  0.084595
*/

** Include Attention as Level-1 and Level-2 Predictor **;

PROC MIXED DATA = ecls_school NOCLPRINT COVTEST;
	CLASS school_id;
	MODEL read_ks = attent_m attent_d / SOLUTION DDFM = BW;
	RANDOM INTERCEPT attent_d/ SUBJECT = school_id TYPE = UN;
RUN;

/*

                                 Covariance Parameter Estimates

                                                    Standard         Z
              Cov Parm     Subject      Estimate       Error     Value        Pr Z

              UN(1,1)      school_id     35.5641      2.1379     16.63      <.0001
              UN(2,1)      school_id     13.8502      1.2733     10.88      <.0001
              UN(2,2)      school_id      6.0285      1.2817      4.70      <.0001
              Residual                    136.69      1.6110     84.85      <.0001


                                         Fit Statistics

                              -2 Res Log Likelihood        126410.5
                              AIC (smaller is better)      126418.5
                              AICC (smaller is better)     126418.5
                              BIC (smaller is better)      126437.6


                                Null Model Likelihood Ratio Test

                                  DF    Chi-Square      Pr > ChiSq

                                   3       2222.61          <.0001


                                   Solution for Fixed Effects

                                         Standard
                Effect       Estimate       Error      DF    t Value    Pr > |t|

                Intercept     46.3177      0.2240     877     206.76      <.0001
                attent_m       7.1316      0.7490     877       9.52      <.0001
                attent_d       7.3701      0.1724    15E3      42.74      <.0001
*/
PROC NLMIXED DATA = ecls_school;
*level-2;
	b_0j = beta_00 + beta_01 * attent_m + u_0j;
	b_1j = beta_10 + u_1j;
*level-1 - without residual term;
	pred = b_0j + b_1j * attent_d;

	MODEL read_ks ~ NORMAL(pred, sigma2_e);
	RANDOM u_0j u_1j ~ NORMAL([0,0], [sigma2_u0,
                                      sigma_u1u0, sigma2_u1]) SUBJECT = school_id;
	PARMS beta_00 = 11 beta_01 = 0
          beta_10 = 0  
          sigma2_u0 = 10 sigma2_u1 = 5 sigma_u1u0 = 0
          sigma2_e = 55;
RUN;


/*
                                          Fit Statistics

                             -2 Log Likelihood                 126409
                             AIC (smaller is better)           126423
                             AICC (smaller is better)          126423
                             BIC (smaller is better)           126456


                                       Parameter Estimates

                        Standard
  Parameter   Estimate     Error    DF  t Value  Pr > |t|   Alpha     Lower     Upper  Gradient

  beta_00      46.3177    0.2238   877   206.95    <.0001    0.05   45.8785   46.7570  0.000309
  beta_01       7.1314    0.7486   877     9.53    <.0001    0.05    5.6621    8.6007  -0.00006
  beta_10       7.3697    0.1731   877    42.57    <.0001    0.05    7.0300    7.7095  -0.00025
  sigma2_u0    35.4858    2.1328   877    16.64    <.0001    0.05   31.2998   39.6718  -0.00002
  sigma2_u1     6.0036    1.2798   877     4.69    <.0001    0.05    3.4918    8.5155  2.978E-6
  sigma_u1u0   13.8426    1.2713   877    10.89    <.0001    0.05   11.3474   16.3379  -0.00004
  sigma2_e      136.69    1.6110   877    84.85    <.0001    0.05    133.53    139.85  -3.72E-7
*/

** Include Hours per Day as Level-2 Predictor **;
DATA ecls_school;
	SET ecls_school;
	hrs_day5 = hrs_day - 5;
RUN;

PROC MIXED DATA = ecls_school NOCLPRINT COVTEST;
	CLASS school_id;
	MODEL read_ks = attent_m attent_d hrs_day5 hrs_day5 * attent_d/ SOLUTION DDFM = BW;
	RANDOM INTERCEPT attent_d/ SUBJECT = school_id TYPE = UN;
RUN;

/*
                                 Covariance Parameter Estimates

                                                    Standard         Z
              Cov Parm     Subject      Estimate       Error     Value        Pr Z

              UN(1,1)      school_id     34.5524      2.0866     16.56      <.0001
              UN(2,1)      school_id     13.7037      1.2551     10.92      <.0001
              UN(2,2)      school_id      6.0577      1.2836      4.72      <.0001
              Residual                    136.66      1.6103     84.87      <.0001


                                         Fit Statistics

                              -2 Res Log Likelihood        126390.4
                              AIC (smaller is better)      126398.4
                              AICC (smaller is better)     126398.4
                              BIC (smaller is better)      126417.5


                                Null Model Likelihood Ratio Test

                                  DF    Chi-Square      Pr > ChiSq

                                   3       2162.37          <.0001


                                   Solution for Fixed Effects

                                             Standard
            Effect               Estimate       Error      DF    t Value    Pr > |t|

            Intercept             46.3630      0.2216     876     209.22      <.0001
            attent_m               7.7017      0.7488     876      10.29      <.0001
            attent_d               7.3924      0.1726    15E3      42.83      <.0001
            hrs_day5               0.6267      0.1301     876       4.82      <.0001
            attent_d*hrs_day5     0.05794      0.1003    15E3       0.58      0.5637
*/


PROC NLMIXED DATA = ecls_school;
*level-2;
	b_0j = beta_00 + beta_01 * attent_m + beta_02 * (hrs_day - 5) + u_0j;
	b_1j = beta_10 + beta_11 * (hrs_day - 5) + u_1j;
*level-1 - without residual term;
	pred = b_0j + b_1j * attent_d;

	MODEL read_ks ~ NORMAL(pred, sigma2_e);
	RANDOM u_0j u_1j ~ NORMAL([0,0], [sigma2_u0,
                                      sigma_u1u0, sigma2_u1]) SUBJECT = school_id;
	PARMS beta_00 = 11 beta_01 = 0
          beta_10 = 0  beta_02 = 0 beta_11 = 0
          sigma2_u0 = 10 sigma2_u1 = 5 sigma_u1u0 = 0
          sigma2_e = 55;
RUN;

/*
                                         Fit Statistics

                             -2 Log Likelihood                 126383
                             AIC (smaller is better)           126401
                             AICC (smaller is better)          126401
                             BIC (smaller is better)           126444


                                       Parameter Estimates

                        Standard
  Parameter   Estimate     Error    DF  t Value  Pr > |t|   Alpha     Lower     Upper  Gradient

  beta_00      46.3630    0.2213   877   209.54    <.0001    0.05   45.9287   46.7973  -0.00075
  beta_01       7.7015    0.7480   877    10.30    <.0001    0.05    6.2334    9.1696  -0.00001
  beta_10       7.3916    0.1731   877    42.70    <.0001    0.05    7.0519    7.7314  0.000217
  beta_02       0.6266    0.1299   877     4.82    <.0001    0.05    0.3717    0.8816  0.001942
  beta_11      0.05809    0.1003   877     0.58    0.5627    0.05   -0.1388    0.2550  0.000253
  sigma2_u0    34.4212    2.0775   877    16.57    <.0001    0.05   30.3438   38.4986  -1.52E-6
  sigma2_u1     5.9957    1.2787   877     4.69    <.0001    0.05    3.4861    8.5054  -0.00009
  sigma_u1u0   13.6750    1.2504   877    10.94    <.0001    0.05   11.2208   16.1292  -0.00002
  sigma2_e      136.66    1.6103   877    84.87    <.0001    0.05    133.50    139.82  -0.00002
*/
